cal : Calendar — amici1

# `cal` : Calendar

See also `lino_xl.lib.cal`.

## Models

## Actors

- Display colors : (no docstring)

- Weekdays : (no docstring)

- YearMonths : (no docstring)

- DurationUnits : (no docstring)

- Recurrencies : (no docstring)

- Access classes : (no docstring)

- Planner columns : (no docstring)

- Task states : (no docstring)

- Presence states : (no docstring)

- Observed events : (no docstring)

- Entry states : (no docstring)

- States : (no docstring)

- Remote Calendars : (no docstring)

- Rooms : (no docstring)

- Rooms : (no docstring)

- Calendars : (no docstring)

- Subscriptions : (no docstring)

- Subscriptions : (no docstring)

- Subscriptions : (no docstring)

- Tasks : (no docstring)

- Tasks : (no docstring)

- Tasks : (no docstring)

- My tasks : (no docstring)

- Tasks : (no docstring)

- Guest roles : (no docstring)

- Presences : (no docstring)

- Presences : (no docstring)

- Presences : (no docstring)

- Presences : (no docstring)

- Presences : (no docstring)

- My presences : (no docstring)

- My pending invitations : (no docstring)

- My guests : (no docstring)

- Calendar entry types : (no docstring)

- Recurring events : (no docstring)

- Calendar entries : (no docstring)

- Calendar entries : (no docstring)

- Calendar entries : (no docstring)

- :doc:` ⚔ <cal.ConflictingEvents>` : (no docstring)

- Calendar entries : (no docstring)

- Appointments today : (no docstring)

- Calendar entries : (no docstring)

- Calendar entries : (no docstring)

- Calendar entries : (no docstring)

- Calendar entries : (no docstring)

- My appointments : (no docstring)

- My appointments today : (no docstring)

- Appointments assigned to me : (no docstring)

- Overdue appointments : (no docstring)

- My overdue appointments : (no docstring)

- My unconfirmed appointments : (no docstring)

- Recurrency policies : (no docstring)